==> apache-camel-4.0.5-src.zip: apache-camel-4.0.5/core/camel-core/src/test/java/org/apache/camel/processor/onexception/RouteScopedOnExceptionLoadBalancerStopRouteTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor.onexception;

import org.apache.camel.builder.RouteBuilder;

public class RouteScopedOnExceptionLoadBalancerStopRouteTest extends ContextScopedOnExceptionLoadBalancerStopRouteTest {

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start").onException(Exception.class).handled(true).loadBalance().roundRobin()
                        .to("seda:error", "seda:error2").end().to("mock:exception").end()
                        // route starts here
                        .to("mock:start").choice().when(body().contains("Kaboom"))
                        .throwException(new IllegalArgumentException("Forced")).otherwise().transform(body().prepend("Bye "))
                        .to("mock:result");

                from("seda:error").routeId("errorRoute").to("controlbus:route?action=stop&routeId=errorRoute&async=true")
                        .to("mock:error");
            }
        };
    }
}

==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/core/camel-core/src/test/java/org/apache/camel/processor/onexception/RouteScopedOnExceptionLoadBalancerStopRouteTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor.onexception;

import org.apache.camel.builder.RouteBuilder;

public class RouteScopedOnExceptionLoadBalancerStopRouteTest extends ContextScopedOnExceptionLoadBalancerStopRouteTest {

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:start").onException(Exception.class).handled(true).loadBalance().roundRobin()
                        .to("seda:error", "seda:error2").end().to("mock:exception").end()
                        // route starts here
                        .to("mock:start").choice().when(body().contains("Kaboom"))
                        .throwException(new IllegalArgumentException("Forced")).otherwise().transform(body().prepend("Bye "))
                        .to("mock:result");

                from("seda:error").routeId("errorRoute").to("controlbus:route?action=stop&routeId=errorRoute&async=true")
                        .to("mock:error");
            }
        };
    }
}
